<?php

namespace Gateway;

use Config\Connection;
use PDO;

class GatewayListResponseOfCandidate
{
    private Connection $connection;

    public function __construct()
    {
        $this->connection = connect();
    }

    public function getDetailsListResponsesOfCandidate(array $idListResponse): void
    {
        $gatewayResponse = new GatewayResponse();
        $gatewayKeyword = new GatewayKeyword();
        $tabKeywords = [];

        $query = "SELECT * FROM ListResponsesOfCandidate WHERE id = :id";
        $this->connection->executeQuery($query, array(
            ':id' => array($idListResponse[0], PDO::PARAM_INT)
        ));

        $questionList = $this->connection->getResults()[0];

        $responses = $gatewayResponse->getResponsesByIdListCandidate($questionList['id']);

        foreach ($responses as $row) {
            $tabKeywords[] = $gatewayKeyword->getKeywordsContentByReference(array($row['id']));
        }

        print(json_encode(array($questionList, $responses, $tabKeywords)));
    }

    public function getAllListResponsesOfCandidate(array $ignore): void
    {
        $query = "SELECT * FROM ListResponsesOfCandidate";
        $this->connection->executeQuery($query);

        print(json_encode($this->connection->getResults()));
    }

    public function deleteListResponseOfCandidate(array $id): void
    {
        $gatewayResponse = new GatewayResponse();

        foreach ( $gatewayResponse->getResponsesIdByIdListCandidate($id[0]) as $response){
            $gatewayResponse->deleteResponseById(array($response));
        }

        $query = "DELETE FROM ListResponsesOfCandidate WHERE id = :id";
        $this->connection->executeQuery($query, array(
            'id' => array($id[0], PDO::PARAM_STR)
        ));
    }

    public function insertListResponsesOfCandidate(array $parameters): void
    {
        $gatewayResponse = new GatewayResponse();
        $gatewayQuestion = new GatewayQuestion();

        $query = "INSERT INTO ListResponsesOfCandidate(date, titleForm) VALUES(:date, :titleForm)";
        $this->connection->executeQuery($query, array(
            ':date' => array(date('Y-m-d H:i:s'), PDO::PARAM_STR),
            ':titleForm' => array($parameters[3], PDO::PARAM_STR)           //parameters[3] = titleForm
        ));

        $idListQuestion = $this->connection->lastInsertId();

        for($i = 0; $i < count($parameters[1]); $i++)                   //parameters[1] = answer
        {
            $idResponse = $gatewayResponse->insertResponse(array($gatewayQuestion->getQuestionContentById(array($parameters[0][$i])), $parameters[1][$i], $parameters[2][$i]));     //parameters[1] = answer, parameters[2] = category, parameters[3] = id

            $query = "INSERT INTO Submit (responsesCandidate, response) VALUES(:responsesCandidate, :response)";
            $this->connection->executeQuery($query, array(
                ':responsesCandidate' => array($idListQuestion, PDO::PARAM_STR),
                'response' => array($idResponse, PDO::PARAM_STR)
            ));
        }
    }
}
