<?php

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Exception\HttpNotFoundException;
use Slim\Factory\AppFactory;

try{
    require 'Config/vendor/autoload.php';

    /**
     * Instantiate App
     */
    $app = AppFactory::create();

    // Add Routing Middleware
    $app->addRoutingMiddleware();

    /**
     * Add Error Handling Middleware
     *
     * @param bool $displayErrorDetails -> Should be set to false in production
     * @param bool $logErrors -> Parameter is passed to the default ErrorHandler
     * @param bool $logErrorDetails -> Display error details in error log
     */
    $errorMiddleware = $app->addErrorMiddleware(true, true, true);
    try {
        $app->get('/', function (Request $request, Response $response) {
            $parameters = $request->getQueryParams();
            $method = $parameters['method'];
            $response->getBody()->write($method);
            $listGateway = array("\\Gateway\\GatewayForm", "\\Gateway\\GatewayKeyword", "\\Gateway\\GatewayQuestion");
            foreach ($listGateway as $gateway) // Pour chaque Gateway
            {
                if (method_exists($gateway, $method)) {
                    (new $gateway)->$method($parameters); // Si oui, on appelle cette fonction
                }
            }
            $response->getBody()->write("Use the method $method, with the parameters ");
            foreach ($parameters as $key => $value) {
                $response->getBody()->write("Key =>" . $key . ", value =>" . $value);
            }
            return $response->withHeader('Content-type', 'application/json');
        });
    }catch (TypeError $t){
    echo "Error, wrong parameters key, or no parameters write : ".$t->getMessage();
    }

    // Run app
    $app->run();
}catch (HttpNotFoundException $e) {
    echo "Error, not Found : " . $e->getMessage();
}

